@@ -142,7 +142,7 @@ class AbstractInterface():
       update_ui = True
     if update_ui: self.__update_ui()
     windex = self.state['value']
-    if show_banner and self.state['banner'][windex]:
+    if self.get_config_value('show-popups') and show_banner and self.state['banner'][windex]:
       text = '%s: %s' % (self.__name, self.__lcl.get_item(self.state['text'][windex]))
       if len(self.state['modes']) > 1:
         text = '%s (%s)' % (text, self.__lcl.get(self.state['modes'][self.state['mode']]))
